============================
Salt 2016.11.1 Release Notes
============================

Version 2016.11.1 is a bugfix release for :ref:`2016.11.0 <release-2016-11-0>`.

Changes for v2016.11.0..v2016.11.1
----------------------------------

Extended changelog courtesy of Todd Stansell (https://github.com/tjstansell/salt-changelogs):

*Generated at: 2016-12-09T21:54:17Z*

Statistics:

- Total Merges: **89**
- Total Issue references: **55**
- Total PR references: **155**

Changes:


- **PR** `#38182`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2016-12-09T21:25:47Z*

  - **PR** `#38177`_: (*vutny*) Correct `cp.get_file_str` docstring and add integration tests
  - **PR** `#38163`_: (*Ch3LL*) enabled ec2 cloud tests
  - **PR** `#38153`_: (*vutny*) Master config includes may contain errors and be safely skipped
  * 23c0393 Merge pull request `#38182`_ from rallytime/merge-2016.11
  * 627242a Merge branch '2016.3' into '2016.11'

    * 65b2ad7 Merge pull request `#38163`_ from Ch3LL/enabled_ec2_cloud

      * be74c45 enabled ec2 cloud tests

    * b63f74e Merge pull request `#38177`_ from vutny/fix-cp-get-file-str

      * a449980 Correct `cp.get_file_str` docstring and add integration tests

    * 7596313 Merge pull request `#38153`_ from vutny/master-includes-error-tolerance

      * cd0154e Master config includes may contain errors and be safely skipped

- **PR** `#38158`_: (*cachedout*) Fix type problem in grains.filter_by
  @ *2016-12-09T21:24:40Z*

  - **ISSUE** `#38094`_: (*bartuss7*) TypeError: object of type 'float' has no len() in grains.filter_by
    | refs: `#38158`_
  * 8355adc Merge pull request `#38158`_ from cachedout/issue_38094
  * e8196e2 Lint, remove set literal

  * 9f4ebb3 Fix type problem in grains.filter_by

- **PR** `#38156`_: (*terminalmage*) Remove rtag when windows minion refreshes early in state
  @ *2016-12-09T21:15:01Z*

  - **ISSUE** `#38090`_: (*jf*) pkg.installed does not seem to refresh the repo database, no matter what
    | refs: `#38113`_ `#38156`_
  * 31a157d Merge pull request `#38156`_ from terminalmage/fix-windows-refresh
  * 258bd4c Remove rtag when windows minion refreshes early in state

- **PR** `#38183`_: (*cro*) Fix bad set operations when setting up securitygroups in AWS.
  @ *2016-12-09T21:12:10Z*

  - **ISSUE** `#37981`_: (*tazaki*) Salt-cloud ec2 vpc securitygroupid always returning default
    | refs: `#38183`_
  - **PR** `#37891`_: (*isbm*) rsync port to 2015.8
  * c638952 Merge pull request `#38183`_ from cro/fix_37891
  * 0527d6f Fix bad set operations when setting up securitygroups in AWS.  Fixes `#37891`_.

* fc95045 Reset socket default timeout to None (fixes daemons_tests failures) (`#38181`_)

  - **PR** `#38181`_: (*rallytime*) Reset socket default timeout to None (fixes daemons_tests failures)

- **PR** `#38148`_: (*whiteinge*) Remove ssh_async from NetapiClient clients; it is not implemented
  @ *2016-12-09T18:49:42Z*

  * 7ccbedd Merge pull request `#38148`_ from whiteinge/no-ssh-async-client
  * cb58cd4 Remove ssh_async from NetapiClient clients; it is not implemented

- **PR** `#38160`_: (*terminalmage*) Update information about xz-utils in archive state/module docs
  @ *2016-12-09T18:34:03Z*

  * 8d4e194 Merge pull request `#38160`_ from terminalmage/update-archive-docs
  * 8e4ad3c Update information about xz-utils in archive state/module docs

- **PR** `#38164`_: (*techhat*) Add Azure ARM docs for 2016.11.0
  @ *2016-12-09T18:00:22Z*

  - **ISSUE** `#38024`_: (*Ch3LL*) 2016.11.0 release notes missing azure arm reference
    | refs: `#38164`_
  * 05136f0 Merge pull request `#38164`_ from techhat/azuredocs
  * 71b787e Add Azure ARM docs for 2016.11.0

- **PR** `#38173`_: (*rallytime*) Bump some win* module deprecations from Nitrogen to Oxygen
  @ *2016-12-09T16:57:29Z*

  * e3c858c Merge pull request `#38173`_ from rallytime/update-win-deprecation-versions
  * 09a50b2 Bump some win* module deprecations from Nitrogen to Oxygen

- **PR** `#38036`_: (*terminalmage*) archive.extracted: fix problems with overwrite arg
  @ *2016-12-08T19:08:41Z*

  - **PR** `#37889`_: (*isbm*) Allow overwrite archives extraction
    | refs: `#38036`_
  * 827bf59 Merge pull request `#38036`_ from terminalmage/archive-extracted-override
  * a1c70c7 archive.extracted: fix problems with overwrite arg

- **PR** `#38133`_: (*terminalmage*) Fix edge case in creation of trans tar for salt-thin
  @ *2016-12-08T17:47:26Z*

  * 50773a5 Merge pull request `#38133`_ from terminalmage/zd1067
  * 71e0bd0 Fix edge case in creation of trans tar for salt-thin

- **PR** `#38138`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2016-12-07T20:15:56Z*

  - **PR** `#38134`_: (*rallytime*) Skip daemon unit tests when running on Python 2.6
  * 6026cb2 Merge pull request `#38138`_ from rallytime/merge-2016.11
  * 28b56ea Merge branch '2016.3' into '2016.11'

  * 86091db Skip daemon unit tests when running on Python 2.6 (`#38134`_)

- **PR** `#38130`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2016-12-07T20:11:19Z*

  - **ISSUE** `#38091`_: (*tjyang*) [WARNING ] salt.loaded.int.module.zenoss.__virtual__() is wrongly returning `None`. 
    | refs: `#38102`_
  - **ISSUE** `#36707`_: (*do3meli*) slow FreeBSD sysctl module with test=true
    | refs: `#36794`_
  - **PR** `#38104`_: (*rallytime*) Back-port `#36794`_ to 2016.3
  - **PR** `#38102`_: (*rallytime*) Add False + msg tuple return if requests is missing for zenoss module
  - **PR** `#36794`_: (*do3meli*) FreeBSD sysctl module now handels config_file parameter in show method
    | refs: `#38104`_
  * 90478ef Merge pull request `#38130`_ from rallytime/merge-2016.11
  * 4d7d9ab Merge branch '2016.3' into '2016.11'

    * d3d98fd4 Merge pull request `#38102`_ from rallytime/`fix-38091`_

      * 4f79d5a Add False + msg tuple return if requests is missing for zenoss module

    * 8c8cbc2 Merge pull request `#38104`_ from rallytime/`bp-36794`_

      * c906c8a Pylint fixes

      * da3ebf8 FreeBSD sysctl module now handels config_file parameter in show method

* 1a42e24 Fix beacon index (`#38129`_)

  - **PR** `#38129`_: (*Ch3LL*) Fix beacon index

* bbdfcab Add versionadded tags for network module funcs (`#38127`_)

  - **PR** `#38127`_: (*rallytime*) Add versionadded tags for network module funcs

- **PR** `#38043`_: (*MTecknology*) Debian networking fix
  @ *2016-12-07T17:32:18Z*

  - **ISSUE** `#38042`_: (*MTecknology*) [2016.11.0] Invalid interfaces file produced by debian_ip module
    | refs: `#38043`_
  * fd06bab Merge pull request `#38043`_ from MTecknology/2016.11
  * 6d5e132 Removing trailing whitespace from previous commit

  * f882674 Adding some options that are valid for inet6 blocks.

  * 81cb688 Better check for dual stack.

  * 525c746 May Cthulhu take mercy on my soul for this commit.

  * 300ca60 I guess this makes the previous commit a bit redundant, but I'm not sure if I want to remove it.

  * 6e7fc39 This now seems absurdly obvious, but I'm not ruling out that I'll break everything.

  * 82d2b89 Rolling back unit test.

  * b3edbcf Adding larger and more complete debian_ip unit test.

  * 3afd7b6 Adding the valid/documented 'slaves' option.

  * b6b1adc Typo: missing closing parenthesis

  * 756e41c Fixing a typo; line should not be commented

  * 32a1374 Corrects expected return value

  * 88f9d9f Mostly whitespace & comment changes

  * 41ffb8d Removing redundant line

  * 3a81686 Ensure iface_dict not being populated will not produce a stacktrace

  * 4de2cb2 Corrects regression in debian_ip/debian_eth.jinja

- **PR** `#38107`_: (*cachedout*) Status beacon should raise proper exception
  @ *2016-12-07T17:21:49Z*

  - **PR** `#38088`_: (*dmurphy18*) Updated to match formulas and allow for missing functions
    | refs: `#38107`_
  * 4b9a7f2 Merge pull request `#38107`_ from cachedout/supercede_38088
  * 73d7248 Change to log.debug per Tom

  * da135b1 Fix docs

  * 792b422 Pylint fix

  * 88e03bb Fix typo

  * a8ce153 Status beacon should raise proper exception

- **PR** `#38101`_: (*lorengordon*) Clarifies file.replace behavior on symlinks
  @ *2016-12-07T13:27:11Z*

  * da8f5ac Merge pull request `#38101`_ from lorengordon/file-replace-note
  * 345990f Clarifies file.replace behavior on symlinks

- **PR** `#38113`_: (*terminalmage*) Revert changes to refresh tag for pkg states
  @ *2016-12-07T13:11:14Z*

  - **ISSUE** `#38090`_: (*jf*) pkg.installed does not seem to refresh the repo database, no matter what
    | refs: `#38113`_ `#38156`_
  * d47761f Merge pull request `#38113`_ from terminalmage/issue38090
  * 9f347df Revert changes to refresh tag for pkg states

- **PR** `#38120`_: (*Da-Juan*) Fix status beacon config default values
  @ *2016-12-07T13:08:33Z*

  - **ISSUE** `#37976`_: (*t0nyhays*) Error when status beacon fires (2016.11.0)
    | refs: `#38120`_
  * d4c34e0 Merge pull request `#38120`_ from Da-Juan/2016.11
  * 7e4a35e Fix status beacon config default values

- **PR** `#38114`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2016-12-07T12:45:04Z*

  - **ISSUE** `#38037`_: (*dmurphy18*) pkg.latest and yumpkg.latest_version return incorrect package versions 2016.3 and 2016.11
    | refs: `#38045`_
  - **ISSUE** `#37939`_: (*Talkless*) file.comment always report changes in test=True mode
    | refs: `#38039`_
  - **ISSUE** `#35342`_: (*morganwillcock*) win_pkg: refresh_db doesn't remove cached items which have been renamed or removed
    | refs: `#38083`_
  - **PR** `#38083`_: (*twangboy*) Only delete .sls files from winrepo-ng [DO NOT MERGE FORWARD]
  - **PR** `#38059`_: (*rallytime*) Call exec_test for the Syndic daemon in tests.unit.daemons_test.py
  - **PR** `#38057`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
    | refs: `#38059`_
  - **PR** `#38045`_: (*terminalmage*) yumpkg.py: don't include non-upgrade versions found by "yum list available"
  - **PR** `#38039`_: (*rallytime*) Check to see if a line is already commented before moving on
  - **PR** `#38034`_: (*cachedout*) Modify daemons test to use multiprocessing
    | refs: `#38059`_
  * 6868089 Merge pull request `#38114`_ from rallytime/merge-2016.11
  * fec9dec Merge branch '2016.3' into '2016.11'

    * fbc8776 Merge pull request `#38083`_ from twangboy/fix_refresh_db

      * 978af6d Remove only .sls files from the cached winrepo-ng

    * 9dcfdee Merge pull request `#38059`_ from rallytime/daemons-test-fix

      * eb372b2 Add missing "not" statement: The last syndic test should assertFalse()

      * 4e10f8e Call exec_test for the Syndic daemon in tests.unit.daemons_test.py

    * 9cd42b9 Merge pull request `#38039`_ from rallytime/`fix-37939`_

      * 1da7aac Update unit tests to account for additional file.search call

      * 8a685b1 Check to see if a line is already commented before moving on

      * f2c0455 Write an integration test demonstrating the issue

    * a34a763 Merge pull request `#38045`_ from terminalmage/issue38037

      * 6528950 Simplify logic for matching desired pkg arch with actual pkg arch

      * 3babbcd yumpkg.py: don't include non-upgrade versions found by "yum list available"

- **PR** `#38109`_: (*gtmanfred*) mode needs to be an integer
  @ *2016-12-07T11:58:24Z*

  * b9920e5 Merge pull request `#38109`_ from gtmanfred/2016.11
  * 7546760 mode needs to be an integer

- **PR** `#38103`_: (*rallytime*) Back-port `#37283`_ to 2016.11
  @ *2016-12-06T23:12:59Z*

  - **PR** `#37283`_: (*jeanpralo*) Handle docker-compose up to version 1.9.0
    | refs: `#38103`_
  - **PR** `#37215`_: (*mschneider82*) removed version check
    | refs: `#37283`_
  * fd77dcb Merge pull request `#38103`_ from rallytime/`bp-37283`_
  * 11944df handle up to version 1.9.0

- **PR** `#38057`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  | refs: `#38059`_
  @ *2016-12-06T23:11:41Z*

  - **ISSUE** `#37945`_: (*gstachowiak*) Missing exception handling in salt.master.Maintenance. Process never completes.
    | refs: `#37961`_
  - **ISSUE** `#37867`_: (*tobiasBora*) Bug into lsb_release that crash salt
    | refs: `#37962`_
  - **ISSUE** `#37737`_: (*b-harper*) python client api CloudClient multiple calls needed
    | refs: `#37928`_
  - **ISSUE** `#37059`_: (*basepi*) Beacon fileserver operations cause scheduled jobs with fileserver operations to hang
    | refs: `#37899`_
  - **ISSUE** `#35088`_: (*Modulus*) salt/cloud/ec2.py encoding problems.
    | refs: `#37912`_
  - **PR** `#38034`_: (*cachedout*) Modify daemons test to use multiprocessing
    | refs: `#38059`_
  - **PR** `#38002`_: (*laleocen*) fix broken yaml code block
  - **PR** `#37995`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
  - **PR** `#37978`_: (*terminalmage*) Add clarifying language to ext_pillar_first docs
  - **PR** `#37964`_: (*terminalmage*) Add clarification on expr_form usage and future deprecation
  - **PR** `#37962`_: (*cachedout*) Catch possible exception from lsb_release
  - **PR** `#37961`_: (*cachedout*) Handle empty tokens safely
  - **PR** `#37950`_: (*vutny*) Set default Salt Master address for a Syndic (like for a Minion)
  - **PR** `#37929`_: (*gtmanfred*) add list_nodes_min to nova driver
  - **PR** `#37928`_: (*techhat*) Don't modify self.opts directly
  - **PR** `#37926`_: (*kontrolld*) Fixes no IPv6 functionality in /etc/sysconfig/network
  - **PR** `#37925`_: (*kontrolld*) Fix missing ipv6 options centos network
  - **PR** `#37924`_: (*cachedout*) Update test for new gem ver
  - **PR** `#37921`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
  - **PR** `#37918`_: (*rallytime*) [2015.8] Update version numbers in doc config for 2016.11.0 release
  - **PR** `#37914`_: (*terminalmage*) Update earlier release channels' docs with Carbon release notes
  - **PR** `#37912`_: (*attiasr*) fix encoding problem aws responses
  - **PR** `#37899`_: (*DmitryKuzmenko*) Clear functions context in schedule tasks for ZeroMQ.
  - **PR** `#37272`_: (*vutny*) Get default logging level and log file from default opts dict
  * 5d9d6b9 Merge pull request `#38057`_ from rallytime/merge-2016.11
  * 3428840 Fix SaltKeyOptionParserTestCase test failures

  * 186e2d0 Don't allow libcloud mock module injection in unit/states/libcloud_dns_test.py either

  * d513a60 Do not allow libcloud to be injected as a mock value in the libcloud_dns_test

  * 74a417e Update the mocked cloud configs to also include master configs

  * f2c8cb1 Better merge conflict resolution from the initial merge

  * 8fd53a4 Merge branch '2016.3' into '2016.11'

    * 6724fe4 Modify daemons test to use multiprocessing (`#38034`_)

    * 6942d5d Merge pull request `#37995`_ from rallytime/merge-2016.3

      * b44e179 Merge branch '2015.8' into '2016.3'

        * 7a7e367 Merge pull request `#37978`_ from terminalmage/ext_pillar_first-docs

          * 61ed9a8 Add clarifying language to ext_pillar_first docs

    * cd66c17 fix broken yaml code block (`#38002`_)

    * 3dd45fb Merge pull request `#37912`_ from attiasr/fix_aws_response_encoding

      * ba4ec4e use Requests result encoding to encode the text

      * abe4eb3 fix encoding problem aws responses

    * 69a74a4 Merge pull request `#37950`_ from vutny/fix-starting-up-syndic

      * 7d9bc9a syndic_master: correct default value, documentation and example config

      * 92a7c7e Set default Salt Master address for a Syndic (like for a Minion)

    * 7f269bc Add clarification on expr_form usage and future deprecation (`#37964`_)

    * 1001987 Catch possible exception from lsb_release (`#37962`_)

    * 330021c Handle empty tokens safely (`#37961`_)

    * ea46639 Merge pull request `#37272`_ from vutny/fix-getting-default-logging-opts

      * e5ce523 Fix description in the Salt Syndic usage info

      * 518a3dd Add unit tests for Salt parsers processing logging options

      * 83d6a44 Add `ssh_log_file` option to master config and documentation

      * c8a0915 Fix configuration example and documentation for `syndic_log_file` option

      * e64dd3e Correct default attributes for various parser classes

      * 82a2e21 Fix default usage string for Salt command line programs

      * 45dffa2 Fix readding and updating logfile and pidfile config options for Salt API

      * f47253c Fix reading and applying Salt Cloud default configuration

      * fad5bec Work with a copy of default opts dictionaries

      * b7c2481 Fix `log_level_logfile` config value type

      * 1bd76a1 Fix setting temporary log level if CLI option omitted

      * 121848c Fix obtaining `log_granular_levels` config setting

      * 44cf07f Make CLI options take precedence for setting up logfile_logger

      * 61afaf1 Fix setting option attributes when processing `log_level` and `log_file`

      * 3c60e23 Fix processing of `log_level_logfile` config setting

      * 55a0af5 Use attribute functions for getting/setting options and config values

      * c25f2d0 Fix getting Salt API default logfile option

      * f242237 Remove processing of unused and undocumented `cli_*_log_*` config options

      * 2065e83 Get default logging level and file from default opts dict

    * f2f957d Merge pull request `#37925`_ from kontrolld/add-ipv6-centos-network

      * ac2b477 Adding IPv6 functionality for CentOS /etc/sysconfig/network

    * c07ad11 Merge pull request `#37899`_ from DSRCorporation/bugs/37059_schedule_task_hang

      * 9497748 Clear functions context in schedule tasks for ZeroMQ.

    * a55519d Merge pull request `#37928`_ from techhat/issue37737

      * a09a60e Don't modify self.opts directly

    * 9d17f1c Merge pull request `#37929`_ from gtmanfred/2016.3

      * c7d2c73 add list_nodes_min to nova driver

    * 3bb743b Merge pull request `#37926`_ from kontrolld/fix-ipv6-centos-network

      * 3ed42e5 updated

      * 3b3bc4f Fixes no IPv6 functionality in /etc/sysconfig/network

    * 271170a Merge pull request `#37921`_ from rallytime/merge-2016.3

      * 523a67c Merge branch '2015.8' into '2016.3'

        * 4cdc6cf Update earlier release channels' docs with Carbon release notes (`#37914`_)

        * d31491a [2015.8] Update version numbers in doc config for 2016.11.0 release (`#37918`_)

    * 6cd6429 Merge pull request `#37924`_ from cachedout/fix_gem_states

      * 894cca3 Update test for new gem ver

* 9969544 Account for case where vim install already exists and is at an older version (`#38112`_)

  - **PR** `#38112`_: (*rallytime*) Account for case where vim install already exists and is at an older version

- **PR** `#38021`_: (*mateiw*) Add master_tops support in salt-ssh
  @ *2016-12-06T14:26:22Z*

  - **ISSUE** `#19502`_: (*kt97679*) salt-ssh fails to run state.highstate with custom master_tops
    | refs: `#38021`_
  * f8c67a9 Merge pull request `#38021`_ from mateiw/salt-ssh_master_tops
  * 65a0f10 Add/remove newlines

  * 7037fa1 Add master_tops support in salt-ssh

* 1bb31bb Start release notes file for 2016.11.1 release (`#38084`_)

  - **PR** `#38084`_: (*rallytime*) Start release notes file for 2016.11.1 release

- **PR** `#37878`_: (*kstreee*) Makes threads avoid blocking waiting while communicating using Zeromq.
  @ *2016-12-05T19:50:46Z*

  * 7829551 Merge pull request `#37878`_ from kstreee/2016.11
  * 9103878 Fixes blocking waiting through implementing a socket pool class.

- **PR** `#37987`_: (*rbjorklin*) consul_pillar support for limiting pillar exposure via minion targeting
  @ *2016-12-05T19:48:20Z*

  - **PR** `#37985`_: (*rbjorklin*) consul_pillar support for limiting pillar exposure via minion targeting
    | refs: `#37987`_
  * 0809ccd Merge pull request `#37987`_ from rbjorklin/consul-pillar-target
  * 5d0454a Ignore W1401 (anomalous-backslash-in-string)

  * 2e929a5 Linting fixes

  * 171cab1 Fixed possible incorrect behavior if target wasn't on start/end of str

  * 7440582 consul_pillar support for limiting pillar exposure via minion targeting

- **PR** `#38067`_: (*terminalmage*) Remove virtual funcs for archive state/module
  @ *2016-12-05T16:37:23Z*

  - **ISSUE** `#38062`_: (*UtahDave*) archive execution module not loading on Windows in 2016.11.0
    | refs: `#38067`_
  * 83dcfe8 Merge pull request `#38067`_ from terminalmage/issue38062
  * 2e0f26a Remove virtual funcs for archive state/module

- **PR** `#38058`_: (*rallytime*) Remove initdb dependency in postgres module
  @ *2016-12-04T04:19:02Z*

  - **ISSUE** `#38001`_: (*tomlaredo*) Regression on postgres_group.present ('postgres_group' __virtual__ returned False)
    | refs: `#38023`_
  - **ISSUE** `#37986`_: (*marek-obuchowicz*) Module postgres - wrong docs, doesn't work with debian 8.5
    | refs: `#38023`_
  - **ISSUE** `#37935`_: (*ipmb*) Postgres module regression on 2016.11
    | refs: `#37946`_ `#37993`_ `#38023`_ `#38058`_
  - **PR** `#38023`_: (*gtmanfred*) Expand error message for postgres states
    | refs: `#38058`_
  - **PR** `#37993`_: (*ticosax*) Remove initdb dependency to consume postgres module.
    | refs: `#38058`_
  * c993367 Merge pull request `#38058`_ from rallytime/remove-init-db-dep
  * c1ceeca Remove initdb dependency in postgres module

- **PR** `#38004`_: (*terminalmage*) Fix regression in user/group mgmt for archive.extracted
  @ *2016-12-02T18:28:49Z*

  - **ISSUE** `#37969`_: (*lordcirth*) Archive.extracted fails if -user: root is specified
    | refs: `#38004`_
  * 1ac53e5 Merge pull request `#38004`_ from terminalmage/issue37969
  * 23bb90a Add integration test for archive.extracted with user/group set to root

  * e5ee721 Don't use simple boolean check on uid/gid

- **PR** `#38051`_: (*Ch3LL*) add docs for hash_type change to sha256
  @ *2016-12-02T18:11:36Z*

  - **ISSUE** `#37941`_: (*L4rS6*) Outdated documentation for 2016.11.x
    | refs: `#38051`_
  * e90cbbe Merge pull request `#38051`_ from Ch3LL/fix_hash_docs
  * e95f88f add docs for hash_type change to sha256

- **PR** `#38028`_: (*terminalmage*) Pass full_return to saltutil.runner
  @ *2016-12-02T09:49:31Z*

  - **ISSUE** `#38000`_: (*morganwillcock*) 2016.11.0: saltutil.runner returns a different dict structure and breaks template rendering
    | refs: `#38028`_
  * 1b52289 Merge pull request `#38028`_ from terminalmage/issue38000
  * 9bf13d5 Pass full_return to saltutil.runner

- **PR** `#38044`_: (*terminalmage*) Remove debugging code
  @ *2016-12-02T09:43:44Z*

  - **ISSUE** `#37980`_: (*tveastman*) Having 'git' in fileserver_backends and no gitfs_remotes defined causes a crash
    | refs: `#38044`_
  * 41c44ff Merge pull request `#38044`_ from terminalmage/issue37980
  * f70a040 Remove debugging code

- **PR** `#38035`_: (*dmurphy18*) Updated to return status from make_repo similar to rpmbuild.py
  @ *2016-12-01T22:30:53Z*

  * 9661258 Merge pull request `#38035`_ from dmurphy18/fix_debbuild
  * 3bca96e Updated to return status from make_repo similar to rpmbuild.py

- **PR** `#38023`_: (*gtmanfred*) Expand error message for postgres states
  | refs: `#38058`_
  @ *2016-12-01T22:05:06Z*

  - **ISSUE** `#38001`_: (*tomlaredo*) Regression on postgres_group.present ('postgres_group' __virtual__ returned False)
    | refs: `#38023`_
  - **ISSUE** `#37986`_: (*marek-obuchowicz*) Module postgres - wrong docs, doesn't work with debian 8.5
    | refs: `#38023`_
  - **ISSUE** `#37935`_: (*ipmb*) Postgres module regression on 2016.11
    | refs: `#37946`_ `#37993`_ `#38023`_ `#38058`_
  * 141b5c5 Merge pull request `#38023`_ from gtmanfred/2016.11
  * 1aa43eb Expand error message for postgres states

  * ac72ee6 Revert "Updated the bins_dir to default to pg_bin `#37935`_"

- **PR** `#38026`_: (*rallytime*) Back-port `#38015`_ to 2016.11
  @ *2016-12-01T19:16:15Z*

  - **PR** `#38015`_: (*morsik*) Typo fix
    | refs: `#38026`_
  * 7948642 Merge pull request `#38026`_ from rallytime/`bp-38015`_
  * 11becf3 Typo fix

* e51448f Added Carbon release notes. Fixed sphinx errors in the file. (`#38022`_)

  - **PR** `#38022`_: (*DmitryKuzmenko*) Added Carbon release notes. Fixed sphinx errors in the file.

* 6f34332 Adjust code examples to use the actual bootstrap-salt.sh file name (`#38011`_)

  - **PR** `#38011`_: (*rallytime*) Adjust code examples to use the actual bootstrap-salt.sh file name

- **PR** `#37954`_: (*gtmanfred*) use sleep from path for docker.sls_build
  @ *2016-11-30T18:08:45Z*

  - **ISSUE** `#37940`_: (*alex-zel*) dockerng.sls_build fails on some distributions
    | refs: `#37954`_
  * 0a04127 Merge pull request `#37954`_ from gtmanfred/2016.11
  * 9caf0b4 use sleep from path for docker.sls_build

- **PR** `#37993`_: (*ticosax*) Remove initdb dependency to consume postgres module.
  | refs: `#38058`_
  @ *2016-11-30T18:08:13Z*

  - **ISSUE** `#37935`_: (*ipmb*) Postgres module regression on 2016.11
    | refs: `#37946`_ `#37993`_ `#38023`_ `#38058`_
  * 4ef5c98 Merge pull request `#37993`_ from ticosax/remove-initdb-requirement
  * c5c7a53 Remove initdb dependency to consume postgres module.

- **PR** `#37997`_: (*cachedout*) Update gem test for 2016.11
  @ *2016-11-30T17:13:45Z*

  * 2e55656 Merge pull request `#37997`_ from cachedout/gem_test_carbon
  * 1d221aa Update gem test for 2016.11

- **PR** `#37979`_: (*terminalmage*) Revert addition of pillar_roots_override_ext_pillar
  @ *2016-11-30T14:34:24Z*

  - **ISSUE** `#36723`_: (*white-hat*) ext_pillar_first option is broken in 2016.3
    | refs: `#36807`_
  - **ISSUE** `#24501`_: (*astehlik*) Order in top.sls file is not respected for pillar data in local mode
    | refs: `#31316`_
  - **ISSUE** `#19332`_: (*QuinnyPig*) Nondeterminism in Pillar
    | refs: `#31316`_
  - **PR** `#36807`_: (*terminalmage*) Fix pillar merging when ext_pillar_first is enabled
    | refs: `#37979`_ `#37979`_
  - **PR** `#31316`_: (*kraney*) Let ext_pillar_first determine the override order
    | refs: `#37979`_ `#37979`_
  * ca3a948 Merge pull request `#37979`_ from terminalmage/revert-pillar-change
  * 6135dfa Revert addition of pillar_roots_override_ext_pillar

* 186b3c7 Fix RST link format (`#37958`_) (`#37970`_)

  - **PR** `#37970`_: (*rallytime*) Back-port `#37958`_ to 2016.11
  - **PR** `#37958`_: (*mirceaulinic*) Fix RST link format in Carbon release notes
    | refs: `#37970`_

* 6976be4 Pylint fix (`#37971`_)

  - **PR** `#37971`_: (*rallytime*) Lint 2016.11 sooner rather than later
  - **PR** `#37955`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
    | refs: `#37971`_

- **PR** `#37946`_: (*scott-w*) Updated the bins_dir to default to pg_bin
  @ *2016-11-29T16:48:27Z*

  - **ISSUE** `#37935`_: (*ipmb*) Postgres module regression on 2016.11
    | refs: `#37946`_ `#37993`_ `#38023`_ `#38058`_
  * 36f9140 Merge pull request `#37946`_ from scott-w/37935-fix-bin-dir
  * d33d403 Restored missing initdb `#37935`_

  * a041b9f Use Salt deprecation warning `#37935`_

  * a967893 Updated the bins_dir to default to pg_bin `#37935`_

- **PR** `#37889`_: (*isbm*) Allow overwrite archives extraction
  | refs: `#38036`_
  @ *2016-11-29T16:18:57Z*

  * d8650c5 Merge pull request `#37889`_ from isbm/isbm-states-archive-fix
  * e67706b Document the behaviour.

  * 1970814 Prevent crash during externally changed archive permissions

  * 91b4257 Add overwrite option so the extraction of the archive can be always performed.

  * e6958f7 Remove nonsense comment and react on generally absent path name

- **PR** `#37869`_: (*isbm*) Input sanitation (16.11)
  @ *2016-11-29T16:17:16Z*

  * e2b9e58 Merge pull request `#37869`_ from isbm/isbm-input-sanitation-16.11
  * f9ec5d6 Use six instead of builtins

  * 203dfcb Use American spelling instead

  * 91ed307 Sanitise input for the keys and IDs

  * 86623f9 Add a stub for ID sanitiser (at the moment same as hostname)

  * 637144c Rename "general.py" to "sanitisers.py"

  * f2571fc Add hostname sanitiser

  * 3ae086a Add filename sanitiser

  * 816b1d1 Add general sanitisers

- **PR** `#37884`_: (*isbm*) Do not include "gpg-pubkey" packages, filtering by their name
  @ *2016-11-28T21:11:37Z*

  * e539a94 Merge pull request `#37884`_ from isbm/isbm-zypper-gpgkey-pkg-filter
  * 038374a Do not include "gpg-pubkey" packages, filtering by their name

- **PR** `#37882`_: (*attiasr*) multiple issues in boto_rds state and module
  @ *2016-11-28T21:09:11Z*

  * eb3d81a Merge pull request `#37882`_ from attiasr/fix_missing_tags
  * 73b3c5f Add newline

  * 166c42b fix boto_rds.describe

  * ddd88ba fix boto_rds.describe  parameters and subnetgroup_present

  * bfe7f92 fix missing tags in call to boto_rds.exists

* 8f986b2 Remove release candidate doc ref from 2016.11.0 release notes (`#37931`_)

  - **PR** `#37931`_: (*rallytime*) Remove release candidate doc ref from 2016.11.0 release notes

- **PR** `#37930`_: (*cachedout*) Remove dictionary comprehension in netusers
  @ *2016-11-28T20:27:06Z*

  * 3d2dabc Merge pull request `#37930`_ from cachedout/fix_comp
  * 670e832 Remove dictionary comprehension in netusers

- **PR** `#37923`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2016-11-28T19:55:03Z*

  - **ISSUE** `#37870`_: (*fj40crawler*) salt.states.augeas.change returns None when test=True
    | refs: `#37895`_
  - **ISSUE** `#37732`_: (*dhaines*) list_semod() (from modules/selinux.py) incompatible with policycoreutils-2.5 (RHEL 7.3)
    | refs: `#37736`_
  - **ISSUE** `#37287`_: (*AaronM-Cloudtek*) salt.states.ddns.present: 'NS' record type always returns as changed
    | refs: `#37785`_
  - **ISSUE** `#32829`_: (*tyhunt99*) Dockerng appears to not be using docker registries pillar data
    | refs: `#36893`_ `#36893`_
  - **PR** `#37916`_: (*rallytime*) [2016.3] Update version numbers in doc config for 2016.11.0 release
  - **PR** `#37907`_: (*Talkless*) Fix server trust in test run of svn.latest
  - **PR** `#37896`_: (*toanju*) rh networking: add missing values
  - **PR** `#37895`_: (*fj40crawler*) Change return value for salt/states/augeas.py to be True instead of N…
  - **PR** `#37886`_: (*bdrung*) Fix various spelling mistakes
  - **PR** `#37866`_: (*meaksh*) Backport `#37149`_ `#36938`_ and `#36784`_ to 2016.3
  - **PR** `#37863`_: (*rallytime*) Back-port `#36893`_ to 2016.3
  - **PR** `#37857`_: (*meaksh*) Backport `#37149`_ and `#36938`_ to 2015.8
    | refs: `#37866`_
  - **PR** `#37856`_: (*meaksh*) Backport `#36784`_ to 2015.8
    | refs: `#37866`_
  - **PR** `#37847`_: (*laleocen*) add multiline encryption documentation to nacl
  - **PR** `#37797`_: (*clan*) check count of columns after split
  - **PR** `#37785`_: (*AaronM-Cloudtek*) respect trailing dot in ddns name parameter
  - **PR** `#37762`_: (*twangboy*) Add pre_versions to chocolatey.installed
  - **PR** `#37736`_: (*dhaines*) handle semodule version >=2.4 (`#37732`_) and fix typo
  - **PR** `#37149`_: (*dincamihai*) Fix pkg.latest_version when latest already installed
    | refs: `#37866`_ `#37857`_
  - **PR** `#36938`_: (*wanparo*) acl.delfacl: fix position of -X option to setfacl
    | refs: `#37866`_ `#37857`_
  - **PR** `#36893`_: (*tyhunt99*) add option to force a reauth for a docker registry
    | refs: `#37863`_
  - **PR** `#36784`_: (*moio*) OS grains for SLES Expanded Support
    | refs: `#37866`_ `#37856`_
  * 0f8b187 Merge pull request `#37923`_ from rallytime/merge-2016.11
  * da7f551 Don't let 2016.3 doc config changes overwrite the 2016.11 changes

  * dfedd11 Merge branch '2016.3' into '2016.11'

    * c35ba1f Merge pull request `#37916`_ from rallytime/doc-update-2016.3

      * bd40592 [2016.3] Update version numbers in doc config for 2016.11.0 release

    * e13a248 Merge pull request `#37785`_ from Cloudtek/ddns-respect-trailing-dot

      * 262e3b3 respect trailing dot in ddns name parameter

    * c03b389 Merge pull request `#37895`_ from fj40crawler/fix-augeas-return-for-test

      * ddc238d Fixed augeas_test.py to match True v.s. None for test_change_in_test_mode

      * ef75c45 Merge branch '2016.3' of github.com:saltstack/salt into fix-augeas-return-for-test

      * b0fe0cd Change return value for salt/states/augeas.py to be True instead of None for cases where salt is run with test=True. Fixes `#37870`_

    * fdbc31e Merge pull request `#37907`_ from Talkless/patch-2

      * 072a319 Fix server trust in test run of svn.latest

    * f39fdf4 Merge pull request `#37896`_ from toanju/2016.3

      * c953041 rh networking: add missing values

    * ea935c5 Merge pull request `#37886`_ from bdrung/fix-typos

      * 9a51ba5 Fix various spelling mistakes

    * 371b0a8 Merge pull request `#37736`_ from dhaines/issue-37732

      * 7ef590a Update selinux.py

      * 516a67e fix indexing error

      * 4e49c1e fix typo

      * b16f2d8 handle semodule version >=2.4 (`#37732`_) and fix typo

    * 87aeb66 Merge pull request `#37797`_ from clan/extfs

      * acf0f96 check count of columns after split

    * f7c7109 Merge pull request `#37762`_ from twangboy/fix_chocolatey_state

      * 9696b6d Use keyword args instead of relying on ordering

      * 398eaa0 Add pre_versions to the available arguments

    * 56baa92 Merge pull request `#37866`_ from meaksh/2016.3-`bp-37149`_-36938-36784

      * 9d8d578 Fix pkg.latest_version when latest already installed

      * ffca0d4 - acl.delfacl: fix position of -X option to setfacl

      * 3dfed6b Adjust linux_acl unit test argument ordering

      * f185ecd core.py: quote style fixed

      * 8404d13 Setting up OS grains for SLES Expanded Support (SUSE's Red Hat compatible platform)

    * d0cc7f0 Merge pull request `#37863`_ from rallytime/`bp-36893`_

      * 4c70534 Add versionadded to reauth option in dockerng module

      * 5ca2c38 added documentation for the new reuth option in docker registry configuration

      * 5b0c11a add option to force a reauth for a docker registry

    * b17a118 add multiline encryption documentation to nacl (`#37847`_)

* 1427115 Add a release notes reference to the docker-sls tutorial (`#37927`_)

  - **PR** `#37927`_: (*thatch45*) Add a release notes reference to the docker-sls tutorial

* d204099 [2016.11] Update version numbers in doc config for 2016.11.0 release (`#37917`_)

  - **PR** `#37917`_: (*rallytime*) [2016.11] Update version numbers in doc config for 2016.11.0 release

- **PR** `#37890`_: (*bbinet*) Fix support for extra_mods='six' to add six module to a thin.tgz tarball
  @ *2016-11-28T13:53:06Z*

  * ee00592 Merge pull request `#37890`_ from bbinet/fix-genthin-six
  * 7fceaa3 Fix support for extra_mods='six' to add six module to a thin.tgz tarball

* 47d21d9 Don't skip pillar compilation when master_type=='disable' (`#37843`_)

  - **ISSUE** `#37713`_: (*aboe76*) masterless minion can't call pillar.item from pillar stack (development branch)
    | refs: `#37843`_
  - **PR** `#37843`_: (*terminalmage*) Don't skip pillar compilation when master_type=='disable'
  - **PR** `#32521`_: (*adelcast*) Fix salt-call on standalone minion case
    | refs: `#37843`_

* 16ce844 Eliminate warning when 'ssl' not set (`#37849`_)

  - **ISSUE** `#37449`_: (*thatch45*) Allow TLS connections in the Tornado TCP transport
    | refs: `#37776`_ `#37859`_
  - **PR** `#37849`_: (*skizunov*) Eliminate warning when 'ssl' not set
  - **PR** `#37776`_: (*DmitryKuzmenko*) Full TLS/SSL options support as provided by Tornado TCPServer.
    | refs: `#37849`_

* 0c607cc An example configuration for TLS/SSL. (`#37859`_)

  - **ISSUE** `#37449`_: (*thatch45*) Allow TLS connections in the Tornado TCP transport
    | refs: `#37776`_ `#37859`_
  - **PR** `#37859`_: (*DmitryKuzmenko*) TLS example config

* 7c1cfa8 Clarify the master_type docs (`#37841`_)

  - **PR** `#37841`_: (*terminalmage*) Clarify the master_type docs

* 2bc42b8 PY3: Fix exception when handling connect exception in TCP transport (`#37831`_)

  - **PR** `#37831`_: (*skizunov*) PY3: Fix exception when handling connect exception in TCP transport

- **PR** `#37829`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2016-11-22T15:26:00Z*

  - **ISSUE** `#37787`_: (*elyulka*) user.present state fails to change loginclass on FreeBSD
    | refs: `#37827`_
  - **ISSUE** `#37751`_: (*freach*) Documentation salt.states.dockerng.running: "privileged" property undocumented
    | refs: `#37789`_
  - **ISSUE** `#37653`_: (*gravyboat*) Salt.cron docs don't wrap @hourly and @daily correctly in quotes for the examples
    | refs: `#37816`_
  - **ISSUE** `#37383`_: (*edwardsdanielj*) Orchestration arguments (kwarg) not being interperted / How I learned to stop worrying about documentation and love experimenting
    | refs: `#37817`_
  - **ISSUE** `#31953`_: (*sjorge*) Documentation for salt.states.cron is incorrect
    | refs: `#32157`_
  - **ISSUE** `#19269`_: (*markuskramerIgitt*) Undocumented  feature `names:` of `file.directory`
    | refs: `#37823`_
  - **ISSUE** `#15697`_: (*arthurlogilab*) keystone.user_present should not re-set the password when user exists
    | refs: `#37821`_
  - **ISSUE** `#5999`_: (*pille*) libvirt.keys does not work
    | refs: `#37820`_
  - **PR** `#37827`_: (*silenius*) add missing chloginclass
  - **PR** `#37826`_: (*rallytime*) Update branch refs to more relevant branch
  - **PR** `#37823`_: (*rallytime*) Add "names" option to file state docs: point users to highstate doc examples
  - **PR** `#37822`_: (*laleocen*) add documenation for multiline encryption using nacl
    | refs: `#37826`_
  - **PR** `#37821`_: (*rallytime*) Clarify keystone.user_present password state docs with default behavior
  - **PR** `#37820`_: (*rallytime*) Add some dependency documentation to libvirt docs
  - **PR** `#37817`_: (*rallytime*) Update orchestrate runner file.copy doc example
  - **PR** `#37816`_: (*rallytime*) Back-port `#32157`_ to 2016.3
  - **PR** `#37812`_: (*rallytime*) Back-port `#37790`_ to 2016.3
  - **PR** `#37811`_: (*rallytime*) Back-port `#37789`_ to 2016.3
  - **PR** `#37810`_: (*rallytime*) Back-port `#37775`_ to 2016.3
  - **PR** `#37790`_: (*sofixa*) Update cloud/proxmox.rst with more options and LXC
    | refs: `#37812`_
  - **PR** `#37789`_: (*fedusia*) issue: 37751
    | refs: `#37811`_
  - **PR** `#37775`_: (*calve*) Document `python` argument in `salt.states.virtualenv_mod`
    | refs: `#37810`_
  - **PR** `#37772`_: (*bdrung*) Support initializing OpenSSL 1.1
  - **PR** `#32157`_: (*cachedout*) Add quotes to cron doc
    | refs: `#37816`_
  * dd81d2f Merge pull request `#37829`_ from rallytime/merge-2016.11
  * 3d6d32e Merge branch '2016.3' into '2016.11'

  * aa37487 add missing chloginclass (`#37827`_)

  * 0e74bad Update branch refs to more relevant branch (`#37826`_)

  * 6a9b49c Add "names" option to file state docs: point users to highstate doc examples (`#37823`_)

  * aaf587d Clarify keystone.user_present password state docs with default behavior (`#37821`_)

  * c300863 Add some dependency documentation to libvirt docs (`#37820`_)

  * 485270f Merge pull request `#37772`_ from bdrung/openssl1.1

    * 819c965 Support initializing OpenSSL 1.1

  * 4910912 Update orchestrate runner file.copy doc example (`#37817`_)

  * c5d3d8b Merge pull request `#37816`_ from rallytime/`bp-32157`_

    * d9c2971 Add quotes to cron doc

  * 97e6b6a Merge pull request `#37812`_ from rallytime/`bp-37790`_

    * ca3b6e7 Update proxmox.rst with more options and LXC

  * 27703c5 Merge pull request `#37811`_ from rallytime/`bp-37789`_

    * ba3fef4  fix comment

    * a021f76 issue: 37751 Add documentation for option privileged

  * adac9d7 Merge pull request `#37810`_ from rallytime/`bp-37775`_

    * 2bed914 Document `python` argument in `salt.states.virtualenv_mod`

* c66b51b network.routes should not raise exception if no interface (`#37794`_)

  - **PR** `#37794`_: (*sjorge*) network.routes should not raise exception if no interface

- **PR** `#37815`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2016-11-21T20:22:49Z*

  - **ISSUE** `#37742`_: (*blaketmiller*) Cannot match on nodegroup when checking minions
    | refs: `#37763`_
  - **ISSUE** `#37725`_: (*secumod*) salt-call incorrectly parses master hostname:port from minion config
    | refs: `#37766`_
  - **PR** `#37766`_: (*cachedout*) Fix ip/port issue with salt-call
  - **PR** `#37763`_: (*cachedout*) Add nodegroup check to ckminions
  * 628c4a3 Merge pull request `#37815`_ from rallytime/merge-2016.11
  * c6b5fd3 Merge branch '2016.3' into '2016.11'

    * 7de7844 Add nodegroup check to ckminions (`#37763`_)

    * d674369 Fix ip/port issue with salt-call (`#37766`_)

- **PR** `#37776`_: (*DmitryKuzmenko*) Full TLS/SSL options support as provided by Tornado TCPServer.
  | refs: `#37849`_
  @ *2016-11-21T20:11:52Z*

  - **ISSUE** `#37449`_: (*thatch45*) Allow TLS connections in the Tornado TCP transport
    | refs: `#37776`_ `#37859`_
  * 0b30b93 Merge pull request `#37776`_ from DSRCorporation/features/37449_tls
  * 6857b9b Documented new TLS/SSL settings.

  * e42898f Full TLS/SSL options support as provided by Tornado TCPServer.

- **PR** `#37773`_: (*rallytime*) [2016.11] Merge forward from 2016.3 to 2016.11
  @ *2016-11-18T19:18:42Z*

  - **ISSUE** `#36629`_: (*yhekma*) The pillar run module does not honor saltenv
    | refs: `#37738`_
  - **ISSUE** `#33709`_: (*msummers42*) Any/All Salt-SSH invocations in 2016.3.0 Fails with AttributeError: 'module' object has no attribute 'BASE_THORIUM_ROOTS_DIR'
    | refs: `#37767`_
  - **PR** `#37767`_: (*cachedout*) Add thorium path to syspaths
  - **PR** `#37760`_: (*hu-dabao*) Fix couchbase returner and add couple of more features
  - **PR** `#37745`_: (*cro*) Switch default filter tag for ONE resources from user only to all resources
  - **PR** `#37738`_: (*terminalmage*) Allow pillar.get to retrieve fresh pillar data when saltenv passed
  * 3835f91 Merge pull request `#37773`_ from rallytime/merge-2016.11
  * c859fc9 Merge branch '2016.3' into '2016.11'

  * c62ff6b Add thorium path to syspaths (`#37767`_)

  * bff949f Merge pull request `#37760`_ from hu-dabao/fix_cb_returner

    * de372f2 1. returner no need to check whether the jid exists for external job cache setup 2. add full_ret to return doc so that the document will be informative 3. make ttl as a config attribute because salt-minion does not have keep_jobs attribute 4. add password into config attribute 5. update the documents accordingly

  * 1f976ac Merge pull request `#37738`_ from terminalmage/issue36629

    * da46678 Allow pillar.get to retrieve fresh pillar data when saltenv passed

  * 7aee7fc Switch default filter tag for ONE resources from user only to all resources (`#37745`_)

- **PR** `#37764`_: (*mirceaulinic*) Doc fixes and `replace` feature
  @ *2016-11-18T03:15:31Z*

  * 6f0f70c Merge pull request `#37764`_ from cloudflare/NET-UPDATE
  * c3f0202 Replace feature and doc fixes


.. _`#15697`: https://github.com/saltstack/salt/issues/15697
.. _`#19269`: https://github.com/saltstack/salt/issues/19269
.. _`#19332`: https://github.com/saltstack/salt/issues/19332
.. _`#19502`: https://github.com/saltstack/salt/issues/19502
.. _`#24501`: https://github.com/saltstack/salt/issues/24501
.. _`#31316`: https://github.com/saltstack/salt/pull/31316
.. _`#31953`: https://github.com/saltstack/salt/issues/31953
.. _`#32157`: https://github.com/saltstack/salt/pull/32157
.. _`#32521`: https://github.com/saltstack/salt/pull/32521
.. _`#32829`: https://github.com/saltstack/salt/issues/32829
.. _`#33709`: https://github.com/saltstack/salt/issues/33709
.. _`#35088`: https://github.com/saltstack/salt/issues/35088
.. _`#35342`: https://github.com/saltstack/salt/issues/35342
.. _`#36629`: https://github.com/saltstack/salt/issues/36629
.. _`#36707`: https://github.com/saltstack/salt/issues/36707
.. _`#36723`: https://github.com/saltstack/salt/issues/36723
.. _`#36784`: https://github.com/saltstack/salt/pull/36784
.. _`#36794`: https://github.com/saltstack/salt/pull/36794
.. _`#36807`: https://github.com/saltstack/salt/pull/36807
.. _`#36893`: https://github.com/saltstack/salt/pull/36893
.. _`#36938`: https://github.com/saltstack/salt/pull/36938
.. _`#37059`: https://github.com/saltstack/salt/issues/37059
.. _`#37149`: https://github.com/saltstack/salt/pull/37149
.. _`#37215`: https://github.com/saltstack/salt/pull/37215
.. _`#37272`: https://github.com/saltstack/salt/pull/37272
.. _`#37283`: https://github.com/saltstack/salt/pull/37283
.. _`#37287`: https://github.com/saltstack/salt/issues/37287
.. _`#37383`: https://github.com/saltstack/salt/issues/37383
.. _`#37449`: https://github.com/saltstack/salt/issues/37449
.. _`#37653`: https://github.com/saltstack/salt/issues/37653
.. _`#37713`: https://github.com/saltstack/salt/issues/37713
.. _`#37725`: https://github.com/saltstack/salt/issues/37725
.. _`#37732`: https://github.com/saltstack/salt/issues/37732
.. _`#37736`: https://github.com/saltstack/salt/pull/37736
.. _`#37737`: https://github.com/saltstack/salt/issues/37737
.. _`#37738`: https://github.com/saltstack/salt/pull/37738
.. _`#37742`: https://github.com/saltstack/salt/issues/37742
.. _`#37745`: https://github.com/saltstack/salt/pull/37745
.. _`#37751`: https://github.com/saltstack/salt/issues/37751
.. _`#37760`: https://github.com/saltstack/salt/pull/37760
.. _`#37762`: https://github.com/saltstack/salt/pull/37762
.. _`#37763`: https://github.com/saltstack/salt/pull/37763
.. _`#37764`: https://github.com/saltstack/salt/pull/37764
.. _`#37766`: https://github.com/saltstack/salt/pull/37766
.. _`#37767`: https://github.com/saltstack/salt/pull/37767
.. _`#37772`: https://github.com/saltstack/salt/pull/37772
.. _`#37773`: https://github.com/saltstack/salt/pull/37773
.. _`#37775`: https://github.com/saltstack/salt/pull/37775
.. _`#37776`: https://github.com/saltstack/salt/pull/37776
.. _`#37785`: https://github.com/saltstack/salt/pull/37785
.. _`#37787`: https://github.com/saltstack/salt/issues/37787
.. _`#37789`: https://github.com/saltstack/salt/pull/37789
.. _`#37790`: https://github.com/saltstack/salt/pull/37790
.. _`#37794`: https://github.com/saltstack/salt/pull/37794
.. _`#37797`: https://github.com/saltstack/salt/pull/37797
.. _`#37810`: https://github.com/saltstack/salt/pull/37810
.. _`#37811`: https://github.com/saltstack/salt/pull/37811
.. _`#37812`: https://github.com/saltstack/salt/pull/37812
.. _`#37815`: https://github.com/saltstack/salt/pull/37815
.. _`#37816`: https://github.com/saltstack/salt/pull/37816
.. _`#37817`: https://github.com/saltstack/salt/pull/37817
.. _`#37820`: https://github.com/saltstack/salt/pull/37820
.. _`#37821`: https://github.com/saltstack/salt/pull/37821
.. _`#37822`: https://github.com/saltstack/salt/pull/37822
.. _`#37823`: https://github.com/saltstack/salt/pull/37823
.. _`#37826`: https://github.com/saltstack/salt/pull/37826
.. _`#37827`: https://github.com/saltstack/salt/pull/37827
.. _`#37829`: https://github.com/saltstack/salt/pull/37829
.. _`#37831`: https://github.com/saltstack/salt/pull/37831
.. _`#37841`: https://github.com/saltstack/salt/pull/37841
.. _`#37843`: https://github.com/saltstack/salt/pull/37843
.. _`#37847`: https://github.com/saltstack/salt/pull/37847
.. _`#37849`: https://github.com/saltstack/salt/pull/37849
.. _`#37856`: https://github.com/saltstack/salt/pull/37856
.. _`#37857`: https://github.com/saltstack/salt/pull/37857
.. _`#37859`: https://github.com/saltstack/salt/pull/37859
.. _`#37863`: https://github.com/saltstack/salt/pull/37863
.. _`#37866`: https://github.com/saltstack/salt/pull/37866
.. _`#37867`: https://github.com/saltstack/salt/issues/37867
.. _`#37869`: https://github.com/saltstack/salt/pull/37869
.. _`#37870`: https://github.com/saltstack/salt/issues/37870
.. _`#37878`: https://github.com/saltstack/salt/pull/37878
.. _`#37882`: https://github.com/saltstack/salt/pull/37882
.. _`#37884`: https://github.com/saltstack/salt/pull/37884
.. _`#37886`: https://github.com/saltstack/salt/pull/37886
.. _`#37889`: https://github.com/saltstack/salt/pull/37889
.. _`#37890`: https://github.com/saltstack/salt/pull/37890
.. _`#37891`: https://github.com/saltstack/salt/pull/37891
.. _`#37895`: https://github.com/saltstack/salt/pull/37895
.. _`#37896`: https://github.com/saltstack/salt/pull/37896
.. _`#37899`: https://github.com/saltstack/salt/pull/37899
.. _`#37907`: https://github.com/saltstack/salt/pull/37907
.. _`#37912`: https://github.com/saltstack/salt/pull/37912
.. _`#37914`: https://github.com/saltstack/salt/pull/37914
.. _`#37916`: https://github.com/saltstack/salt/pull/37916
.. _`#37917`: https://github.com/saltstack/salt/pull/37917
.. _`#37918`: https://github.com/saltstack/salt/pull/37918
.. _`#37921`: https://github.com/saltstack/salt/pull/37921
.. _`#37923`: https://github.com/saltstack/salt/pull/37923
.. _`#37924`: https://github.com/saltstack/salt/pull/37924
.. _`#37925`: https://github.com/saltstack/salt/pull/37925
.. _`#37926`: https://github.com/saltstack/salt/pull/37926
.. _`#37927`: https://github.com/saltstack/salt/pull/37927
.. _`#37928`: https://github.com/saltstack/salt/pull/37928
.. _`#37929`: https://github.com/saltstack/salt/pull/37929
.. _`#37930`: https://github.com/saltstack/salt/pull/37930
.. _`#37931`: https://github.com/saltstack/salt/pull/37931
.. _`#37935`: https://github.com/saltstack/salt/issues/37935
.. _`#37939`: https://github.com/saltstack/salt/issues/37939
.. _`#37940`: https://github.com/saltstack/salt/issues/37940
.. _`#37941`: https://github.com/saltstack/salt/issues/37941
.. _`#37945`: https://github.com/saltstack/salt/issues/37945
.. _`#37946`: https://github.com/saltstack/salt/pull/37946
.. _`#37950`: https://github.com/saltstack/salt/pull/37950
.. _`#37954`: https://github.com/saltstack/salt/pull/37954
.. _`#37955`: https://github.com/saltstack/salt/pull/37955
.. _`#37958`: https://github.com/saltstack/salt/pull/37958
.. _`#37961`: https://github.com/saltstack/salt/pull/37961
.. _`#37962`: https://github.com/saltstack/salt/pull/37962
.. _`#37964`: https://github.com/saltstack/salt/pull/37964
.. _`#37969`: https://github.com/saltstack/salt/issues/37969
.. _`#37970`: https://github.com/saltstack/salt/pull/37970
.. _`#37971`: https://github.com/saltstack/salt/pull/37971
.. _`#37976`: https://github.com/saltstack/salt/issues/37976
.. _`#37978`: https://github.com/saltstack/salt/pull/37978
.. _`#37979`: https://github.com/saltstack/salt/pull/37979
.. _`#37980`: https://github.com/saltstack/salt/issues/37980
.. _`#37981`: https://github.com/saltstack/salt/issues/37981
.. _`#37985`: https://github.com/saltstack/salt/pull/37985
.. _`#37986`: https://github.com/saltstack/salt/issues/37986
.. _`#37987`: https://github.com/saltstack/salt/pull/37987
.. _`#37993`: https://github.com/saltstack/salt/pull/37993
.. _`#37995`: https://github.com/saltstack/salt/pull/37995
.. _`#37997`: https://github.com/saltstack/salt/pull/37997
.. _`#38000`: https://github.com/saltstack/salt/issues/38000
.. _`#38001`: https://github.com/saltstack/salt/issues/38001
.. _`#38002`: https://github.com/saltstack/salt/pull/38002
.. _`#38004`: https://github.com/saltstack/salt/pull/38004
.. _`#38011`: https://github.com/saltstack/salt/pull/38011
.. _`#38015`: https://github.com/saltstack/salt/pull/38015
.. _`#38021`: https://github.com/saltstack/salt/pull/38021
.. _`#38022`: https://github.com/saltstack/salt/pull/38022
.. _`#38023`: https://github.com/saltstack/salt/pull/38023
.. _`#38024`: https://github.com/saltstack/salt/issues/38024
.. _`#38026`: https://github.com/saltstack/salt/pull/38026
.. _`#38028`: https://github.com/saltstack/salt/pull/38028
.. _`#38034`: https://github.com/saltstack/salt/pull/38034
.. _`#38035`: https://github.com/saltstack/salt/pull/38035
.. _`#38036`: https://github.com/saltstack/salt/pull/38036
.. _`#38037`: https://github.com/saltstack/salt/issues/38037
.. _`#38039`: https://github.com/saltstack/salt/pull/38039
.. _`#38042`: https://github.com/saltstack/salt/issues/38042
.. _`#38043`: https://github.com/saltstack/salt/pull/38043
.. _`#38044`: https://github.com/saltstack/salt/pull/38044
.. _`#38045`: https://github.com/saltstack/salt/pull/38045
.. _`#38051`: https://github.com/saltstack/salt/pull/38051
.. _`#38057`: https://github.com/saltstack/salt/pull/38057
.. _`#38058`: https://github.com/saltstack/salt/pull/38058
.. _`#38059`: https://github.com/saltstack/salt/pull/38059
.. _`#38062`: https://github.com/saltstack/salt/issues/38062
.. _`#38067`: https://github.com/saltstack/salt/pull/38067
.. _`#38083`: https://github.com/saltstack/salt/pull/38083
.. _`#38084`: https://github.com/saltstack/salt/pull/38084
.. _`#38088`: https://github.com/saltstack/salt/pull/38088
.. _`#38090`: https://github.com/saltstack/salt/issues/38090
.. _`#38091`: https://github.com/saltstack/salt/issues/38091
.. _`#38094`: https://github.com/saltstack/salt/issues/38094
.. _`#38101`: https://github.com/saltstack/salt/pull/38101
.. _`#38102`: https://github.com/saltstack/salt/pull/38102
.. _`#38103`: https://github.com/saltstack/salt/pull/38103
.. _`#38104`: https://github.com/saltstack/salt/pull/38104
.. _`#38107`: https://github.com/saltstack/salt/pull/38107
.. _`#38109`: https://github.com/saltstack/salt/pull/38109
.. _`#38112`: https://github.com/saltstack/salt/pull/38112
.. _`#38113`: https://github.com/saltstack/salt/pull/38113
.. _`#38114`: https://github.com/saltstack/salt/pull/38114
.. _`#38120`: https://github.com/saltstack/salt/pull/38120
.. _`#38127`: https://github.com/saltstack/salt/pull/38127
.. _`#38129`: https://github.com/saltstack/salt/pull/38129
.. _`#38130`: https://github.com/saltstack/salt/pull/38130
.. _`#38133`: https://github.com/saltstack/salt/pull/38133
.. _`#38134`: https://github.com/saltstack/salt/pull/38134
.. _`#38138`: https://github.com/saltstack/salt/pull/38138
.. _`#38148`: https://github.com/saltstack/salt/pull/38148
.. _`#38153`: https://github.com/saltstack/salt/pull/38153
.. _`#38156`: https://github.com/saltstack/salt/pull/38156
.. _`#38158`: https://github.com/saltstack/salt/pull/38158
.. _`#38160`: https://github.com/saltstack/salt/pull/38160
.. _`#38163`: https://github.com/saltstack/salt/pull/38163
.. _`#38164`: https://github.com/saltstack/salt/pull/38164
.. _`#38173`: https://github.com/saltstack/salt/pull/38173
.. _`#38177`: https://github.com/saltstack/salt/pull/38177
.. _`#38181`: https://github.com/saltstack/salt/pull/38181
.. _`#38182`: https://github.com/saltstack/salt/pull/38182
.. _`#38183`: https://github.com/saltstack/salt/pull/38183
.. _`#5999`: https://github.com/saltstack/salt/issues/5999
.. _`bp-32157`: https://github.com/saltstack/salt/pull/32157
.. _`bp-36794`: https://github.com/saltstack/salt/pull/36794
.. _`bp-36893`: https://github.com/saltstack/salt/pull/36893
.. _`bp-37149`: https://github.com/saltstack/salt/pull/37149
.. _`bp-37283`: https://github.com/saltstack/salt/pull/37283
.. _`bp-37775`: https://github.com/saltstack/salt/pull/37775
.. _`bp-37789`: https://github.com/saltstack/salt/pull/37789
.. _`bp-37790`: https://github.com/saltstack/salt/pull/37790
.. _`bp-38015`: https://github.com/saltstack/salt/pull/38015
.. _`fix-37939`: https://github.com/saltstack/salt/issues/37939
.. _`fix-38091`: https://github.com/saltstack/salt/issues/38091
